#[repr(C)]pub struct U8Vec2 {
pub x: u8,
pub y: u8,
}Expand description
A 2-dimensional vector.
Fields
x: u8y: u8Implementations
Sourceimpl U8Vec2
impl U8Vec2
Sourcepub fn map<F>(self, f: F) -> U8Vec2
pub fn map<F>(self, f: F) -> U8Vec2
Returns a vector containing each element of self modified by a mapping function f.
Sourcepub fn select(mask: BVec2, if_true: U8Vec2, if_false: U8Vec2) -> U8Vec2
pub fn select(mask: BVec2, if_true: U8Vec2, if_false: U8Vec2) -> U8Vec2
Creates a vector from the elements in if_true and if_false, selecting which to use
for each element of self.
A true element in the mask uses the corresponding element from if_true, and false
uses the element from if_false.
Sourcepub const fn from_array(a: [u8; 2]) -> U8Vec2
pub const fn from_array(a: [u8; 2]) -> U8Vec2
Creates a new vector from an array.
Sourcepub const fn from_slice(slice: &[u8]) -> U8Vec2
pub const fn from_slice(slice: &[u8]) -> U8Vec2
Creates a vector from the first 2 values in slice.
Panics
Panics if slice is less than 2 elements long.
Sourcepub fn write_to_slice(self, slice: &mut [u8])
pub fn write_to_slice(self, slice: &mut [u8])
Writes the elements of self to the first 2 elements in slice.
Panics
Panics if slice is less than 2 elements long.
Sourcepub const fn extend(self, z: u8) -> U8Vec3
pub const fn extend(self, z: u8) -> U8Vec3
Creates a 3D vector from self and the given z value.
Sourcepub fn dot_into_vec(self, rhs: U8Vec2) -> U8Vec2
pub fn dot_into_vec(self, rhs: U8Vec2) -> U8Vec2
Returns a vector where every component is the dot product of self and rhs.
Sourcepub fn min(self, rhs: U8Vec2) -> U8Vec2
pub fn min(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the minimum values for each element of self and rhs.
In other words this computes [self.x.min(rhs.x), self.y.min(rhs.y), ..].
Sourcepub fn max(self, rhs: U8Vec2) -> U8Vec2
pub fn max(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the maximum values for each element of self and rhs.
In other words this computes [self.x.max(rhs.x), self.y.max(rhs.y), ..].
Sourcepub fn min_element(self) -> u8
pub fn min_element(self) -> u8
Returns the horizontal minimum of self.
In other words this computes min(x, y, ..).
Sourcepub fn max_element(self) -> u8
pub fn max_element(self) -> u8
Returns the horizontal maximum of self.
In other words this computes max(x, y, ..).
Sourcepub fn element_sum(self) -> u8
pub fn element_sum(self) -> u8
Returns the sum of all elements of self.
In other words, this computes self.x + self.y + ...
Sourcepub fn element_product(self) -> u8
pub fn element_product(self) -> u8
Returns the product of all elements of self.
In other words, this computes self.x * self.y * ...
Sourcepub fn cmpeq(self, rhs: U8Vec2) -> BVec2
pub fn cmpeq(self, rhs: U8Vec2) -> BVec2
Returns a vector mask containing the result of a == comparison for each element of
self and rhs.
In other words, this computes [self.x == rhs.x, self.y == rhs.y, ..] for all
elements.
Sourcepub fn cmpne(self, rhs: U8Vec2) -> BVec2
pub fn cmpne(self, rhs: U8Vec2) -> BVec2
Returns a vector mask containing the result of a != comparison for each element of
self and rhs.
In other words this computes [self.x != rhs.x, self.y != rhs.y, ..] for all
elements.
Sourcepub fn cmpge(self, rhs: U8Vec2) -> BVec2
pub fn cmpge(self, rhs: U8Vec2) -> BVec2
Returns a vector mask containing the result of a >= comparison for each element of
self and rhs.
In other words this computes [self.x >= rhs.x, self.y >= rhs.y, ..] for all
elements.
Sourcepub fn cmpgt(self, rhs: U8Vec2) -> BVec2
pub fn cmpgt(self, rhs: U8Vec2) -> BVec2
Returns a vector mask containing the result of a > comparison for each element of
self and rhs.
In other words this computes [self.x > rhs.x, self.y > rhs.y, ..] for all
elements.
Sourcepub fn cmple(self, rhs: U8Vec2) -> BVec2
pub fn cmple(self, rhs: U8Vec2) -> BVec2
Returns a vector mask containing the result of a <= comparison for each element of
self and rhs.
In other words this computes [self.x <= rhs.x, self.y <= rhs.y, ..] for all
elements.
Sourcepub fn cmplt(self, rhs: U8Vec2) -> BVec2
pub fn cmplt(self, rhs: U8Vec2) -> BVec2
Returns a vector mask containing the result of a < comparison for each element of
self and rhs.
In other words this computes [self.x < rhs.x, self.y < rhs.y, ..] for all
elements.
Sourcepub fn length_squared(self) -> u8
pub fn length_squared(self) -> u8
Computes the squared length of self.
Sourcepub fn as_i16vec2(&self) -> I16Vec2
pub fn as_i16vec2(&self) -> I16Vec2
Casts all elements of self to i16.
Sourcepub fn as_u16vec2(&self) -> U16Vec2
pub fn as_u16vec2(&self) -> U16Vec2
Casts all elements of self to u16.
Sourcepub fn as_i64vec2(&self) -> I64Vec2
pub fn as_i64vec2(&self) -> I64Vec2
Casts all elements of self to i64.
Sourcepub fn as_u64vec2(&self) -> U64Vec2
pub fn as_u64vec2(&self) -> U64Vec2
Casts all elements of self to u64.
Sourcepub const fn wrapping_add(self, rhs: U8Vec2) -> U8Vec2
pub const fn wrapping_add(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the wrapping addition of self and rhs.
In other words this computes [self.x.wrapping_add(rhs.x), self.y.wrapping_add(rhs.y), ..].
Sourcepub const fn wrapping_sub(self, rhs: U8Vec2) -> U8Vec2
pub const fn wrapping_sub(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the wrapping subtraction of self and rhs.
In other words this computes [self.x.wrapping_sub(rhs.x), self.y.wrapping_sub(rhs.y), ..].
Sourcepub const fn wrapping_mul(self, rhs: U8Vec2) -> U8Vec2
pub const fn wrapping_mul(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the wrapping multiplication of self and rhs.
In other words this computes [self.x.wrapping_mul(rhs.x), self.y.wrapping_mul(rhs.y), ..].
Sourcepub const fn wrapping_div(self, rhs: U8Vec2) -> U8Vec2
pub const fn wrapping_div(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the wrapping division of self and rhs.
In other words this computes [self.x.wrapping_div(rhs.x), self.y.wrapping_div(rhs.y), ..].
Sourcepub const fn saturating_add(self, rhs: U8Vec2) -> U8Vec2
pub const fn saturating_add(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the saturating addition of self and rhs.
In other words this computes [self.x.saturating_add(rhs.x), self.y.saturating_add(rhs.y), ..].
Sourcepub const fn saturating_sub(self, rhs: U8Vec2) -> U8Vec2
pub const fn saturating_sub(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the saturating subtraction of self and rhs.
In other words this computes [self.x.saturating_sub(rhs.x), self.y.saturating_sub(rhs.y), ..].
Sourcepub const fn saturating_mul(self, rhs: U8Vec2) -> U8Vec2
pub const fn saturating_mul(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the saturating multiplication of self and rhs.
In other words this computes [self.x.saturating_mul(rhs.x), self.y.saturating_mul(rhs.y), ..].
Sourcepub const fn saturating_div(self, rhs: U8Vec2) -> U8Vec2
pub const fn saturating_div(self, rhs: U8Vec2) -> U8Vec2
Returns a vector containing the saturating division of self and rhs.
In other words this computes [self.x.saturating_div(rhs.x), self.y.saturating_div(rhs.y), ..].
Sourcepub const fn wrapping_add_signed(self, rhs: I8Vec2) -> U8Vec2
pub const fn wrapping_add_signed(self, rhs: I8Vec2) -> U8Vec2
Returns a vector containing the wrapping addition of self and signed vector rhs.
In other words this computes [self.x.wrapping_add_signed(rhs.x), self.y.wrapping_add_signed(rhs.y), ..].
Sourcepub const fn saturating_add_signed(self, rhs: I8Vec2) -> U8Vec2
pub const fn saturating_add_signed(self, rhs: I8Vec2) -> U8Vec2
Returns a vector containing the saturating addition of self and signed vector rhs.
In other words this computes [self.x.saturating_add_signed(rhs.x), self.y.saturating_add_signed(rhs.y), ..].